@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Dict
+
 from sqlalchemy import and_
 from sqlalchemy.orm import joinedload
 
@@ -21,30 +23,24 @@ from pyramid.view import view_config
 
 from ... import security, resource
 from ...models import MetaDatum, MetaDataSet, MetaDatumRecord, File
-from ..metadatasets import MetaDataSetResponse, get_record_from_metadataset
+from ..metadatasets import MetaDataSetResponse
+from ...utils import get_record_from_metadataset
+from ..metadata import get_all_metadata
 from ..files import FileResponse
-from .convert import formatted_mrec_value
 
-####################################################################################################
 
-def get_pending_metadatasets(dbsession, user):
+def get_pending_metadatasets(dbsession, user, metadata: Dict[str, MetaDatum]):
     # Query metadatasets that have been no associated submission
     m_sets = dbsession.query(MetaDataSet).filter(and_(
-        MetaDataSet.user==user,
-        MetaDataSet.submission==None)
+        MetaDataSet.user == user,
+        MetaDataSet.submission.is_(None))
         ).options(
                 joinedload(MetaDataSet.metadatumrecords).joinedload(MetaDatumRecord.metadatum)
                 ).all()
-
-    metadata_query = dbsession.query(MetaDatum).order_by(
-        MetaDatum.order
-    ).all()
-    metadata = {mdat.name: mdat for mdat in metadata_query }
-
     return [
             MetaDataSetResponse(
                 id             = resource.get_identifier(m_set),
-                record         = get_record_from_metadataset(m_set),
+                record         = get_record_from_metadataset(m_set, metadata),
                 file_ids       = { name : None for name, metadatum in metadata.items() if metadatum.isfile },
                 user_id        = resource.get_identifier(m_set.user),
                 submission_id  = resource.get_identifier(m_set.submission) if m_set.submission else None
@@ -52,11 +48,10 @@ def get_pending_metadatasets(dbsession, user):
             for m_set in m_sets
             ]
 
-####################################################################################################
 
 def get_pending_files(dbsession, user):
     # Find files that have not yet been associated with metadata
-    db_files = dbsession.query(File).filter(and_(File.user_id==user.id, File.metadatumrecord==None, File.content_uploaded==True)).order_by(File.id.desc())
+    db_files = dbsession.query(File).filter(and_(File.user_id == user.id, File.metadatumrecord.is_(None), File.content_uploaded.is_(True))).order_by(File.id.desc())
     return [
             FileResponse(
                 id                = resource.get_identifier(db_file),
@@ -69,7 +64,6 @@ def get_pending_files(dbsession, user):
                 ) for db_file in db_files
             ]
 
-####################################################################################################
 
 @view_config(
     route_name      = "pending",
@@ -87,13 +81,13 @@ def get(request: Request) -> HTTPOk:
     auth_user = security.revalidate_user(request)
 
     # Query metadata fields
-    mdats = db.query(MetaDatum).order_by(MetaDatum.order).all()
-    mdat_names = [ mdat.name for mdat in mdats ]
-    mdat_names_files = [ mdat.name for mdat in mdats if mdat.isfile ]
+    metadata = get_all_metadata(db, include_service_metadata = False)
+    mdat_names = list(metadata.keys())
+    mdat_names_files = [ mdat_name for mdat_name, mdat in metadata.items() if mdat.isfile ]
 
     return {
             'metadataKeys'       : mdat_names,
             'metadataKeysFiles'  : mdat_names_files,
-            'metadatasets'       : get_pending_metadatasets(db, auth_user),
+            'metadatasets'       : get_pending_metadatasets(db, auth_user, metadata),
             'files'              : get_pending_files(db, auth_user)
             }
